GsInfo

Struct GsInfo 

#[repr(C, align(64))]
pub struct GsInfo { self_ptr: AtomicU64, kernel_stack_top: AtomicU64, user_rsp: AtomicU64, }
A per-CPU struct which each CPU’s GS kernel reg points to in order to handle syscall entry

Fields

self_ptr: AtomicU64kernel_stack_top: AtomicU64user_rsp: AtomicU64

Implementations

Source

impl GsInfo

pub const fn new() -> Self

Construct a new zeroed instance of GsInfo

pub unsafe fn init(&'static self)

Initialize the given GsInfo

Safety

The caller must guarantee the following:

  • This method is called exactly once on the CPU which owns the given GsInfo
  • This method is called before the first jump to userspace on the CPU which owns the given GsInfo
pub unsafe fn set_kernel_stack_top(&self, kernel_stack_top: VirtAddr)

Set the kernel stack top of the given GsInfo

Safety

The caller must ensure that kernel_stack_top is a valid pointer to a valid, mapped kernel stack

pub fn self_ptr(&self) -> u64

Getter for GsInfo::self_ptr

pub fn kernel_stack_top(&self) -> u64

Getter for GsInfo::kernel_stack_top

pub fn user_rsp(&self) -> u64

Getter for GsInfo::user_rsp